@@ -1,5 +1,8 @@
 //! Ranges for specifying downloads
-use std::ops::{Range, RangeFrom, RangeFull, RangeInclusive, RangeTo, RangeToInclusive};
+use std::{
+    fmt,
+    ops::{Range, RangeFrom, RangeFull, RangeInclusive, RangeTo, RangeToInclusive},
+};
 
 use crate::errors::CondowError;
 
@@ -41,6 +44,12 @@ impl InclusiveRange {
     }
 }
 
+impl fmt::Display for InclusiveRange {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "{}..={}", self.0, self.1)
+    }
+}
+
 impl From<RangeInclusive<usize>> for InclusiveRange {
     fn from(ri: RangeInclusive<usize>) -> Self {
         Self(*ri.start(), *ri.end())
@@ -81,7 +90,7 @@ impl ClosedRange {
         match self {
             Self::FromTo(a, b) => {
                 if b < a {
-                    Err(CondowError::InvalidRange(format!(
+                    Err(CondowError::new_invalid_range(format!(
                         "FromTo: 'to'({}) must be lesser or equal than 'from'({})",
                         a, b
                     )))
@@ -91,7 +100,7 @@ impl ClosedRange {
             }
             Self::FromToInclusive(a, b) => {
                 if b < a {
-                    Err(CondowError::InvalidRange(format!(
+                    Err(CondowError::new_invalid_range(format!(
                         "FromToInclusive: 'to'({}) must be lesser or equal than 'from'({})",
                         a, b
                     )))
@@ -221,6 +230,50 @@ impl OpenRange {
 /// A range which specifies a download
 ///
 /// Conversions for the standard Rust range syntax exist.
+///
+/// # Examples
+///
+/// ```rust
+/// # use condow_core::*;
+/// let dl = DownloadRange::from(..);
+/// assert_eq!(dl, DownloadRange::Open(OpenRange::Full));
+/// ```
+///
+/// ```rust
+/// # use condow_core::*;
+/// let dl = DownloadRange::from(3..);
+/// assert_eq!(dl, DownloadRange::Open(OpenRange::From(3)));
+/// ```
+///
+/// ```rust
+/// # use condow_core::*;
+/// let dl = DownloadRange::from(5..10);
+/// assert_eq!(dl, DownloadRange::Closed(ClosedRange::FromTo(5,10)));
+/// ```
+///
+/// ```rust
+/// # use condow_core::*;
+/// let dl = DownloadRange::from(5..=10);
+/// assert_eq!(dl, DownloadRange::Closed(ClosedRange::FromToInclusive(5, 10)));
+/// ```
+///
+/// ```rust
+/// # use condow_core::*;
+/// let dl = DownloadRange::from(..7);
+/// assert_eq!(dl, DownloadRange::Closed(ClosedRange::To(7)));
+/// ```
+///
+/// ```rust
+/// # use condow_core::*;
+/// let dl = DownloadRange::from(..=7);
+/// assert_eq!(dl, DownloadRange::Closed(ClosedRange::ToInclusive(7)));
+/// ```
+///
+/// ```rust
+/// # use condow_core::*;
+/// let dl = DownloadRange::from(InclusiveRange(1, 7));
+/// assert_eq!(dl, DownloadRange::Closed(ClosedRange::FromToInclusive(1,7)));
+/// ```
 #[derive(Debug, Clone, Copy, PartialEq)]
 pub enum DownloadRange {
     Open(OpenRange),
