@@ -5,8 +5,9 @@ use futures::future::BoxFuture;
 
 use crate::{
     condow_client::CondowClient,
-    errors::{CondowError, GetSizeError},
-    reporter::{NoReporting, Reporter, ReporterFactory},
+    errors::CondowError,
+    machinery,
+    reporter::{CompositeReporter, NoReporting, Reporter, ReporterFactory},
     streams::{ChunkStream, PartStream},
     Condow, DownloadRange, Downloads, GetSizeMode, StreamWithReport,
 };
@@ -45,6 +46,7 @@ impl<C: CondowClient, RF: ReporterFactory> DownloadSession<C, RF> {
         self
     }
 
+    /// Returns a reference to the [ReporterFactory].
     pub fn reporter_factory(&self) -> &RF {
         self.reporter_factory.as_ref()
     }
@@ -78,10 +80,15 @@ impl<C: CondowClient, RF: ReporterFactory> DownloadSession<C, RF> {
         location: C::Location,
         range: R,
     ) -> Result<ChunkStream, CondowError> {
-        self.condow
-            .download_chunks_internal(location, range, self.get_size_mode, NoReporting)
-            .await
-            .map(|o| o.stream)
+        machinery::start_download(
+            &self.condow,
+            location,
+            range,
+            self.get_size_mode,
+            NoReporting,
+        )
+        .await
+        .map(|o| o.stream)
     }
 
     /// Download the BLOB/range and report events.
@@ -160,8 +167,7 @@ impl<C: CondowClient, RF: ReporterFactory> DownloadSession<C, RF> {
         reporter: RPP,
     ) -> Result<StreamWithReport<ChunkStream, RPP>, CondowError> {
         let composite = CompositeReporter(self.reporter_factory.make(), reporter);
-        self.condow
-            .download_chunks_internal(location, range, self.get_size_mode, composite)
+        machinery::start_download(&self.condow, location, range, self.get_size_mode, composite)
             .await
             .map(|sr| {
                 let StreamWithReport { stream, reporter } = sr;
@@ -173,7 +179,7 @@ impl<C: CondowClient, RF: ReporterFactory> DownloadSession<C, RF> {
     }
 
     /// Get the size of a file at the BLOB at location
-    pub async fn get_size(&self, location: C::Location) -> Result<usize, GetSizeError> {
+    pub async fn get_size(&self, location: C::Location) -> Result<usize, CondowError> {
         self.condow.get_size(location).await
     }
 }
@@ -209,54 +215,3 @@ where
         Box::pin(self.download_chunks(location, range))
     }
 }
-
-#[derive(Clone)]
-struct CompositeReporter<RA: Reporter, RB: Reporter>(RA, RB);
-
-impl<RA: Reporter, RB: Reporter> Reporter for CompositeReporter<RA, RB> {
-    fn effective_range(&self, range: crate::InclusiveRange) {
-        self.0.effective_range(range);
-        self.1.effective_range(range);
-    }
-
-    fn download_started(&self) {
-        self.0.download_started();
-        self.1.download_started();
-    }
-
-    fn download_completed(&self) {
-        self.0.download_completed();
-        self.1.download_completed();
-    }
-
-    fn download_failed(&self) {
-        self.0.download_failed();
-        self.1.download_failed();
-    }
-
-    fn queue_full(&self) {
-        self.0.queue_full();
-        self.1.queue_full();
-    }
-
-    fn chunk_completed(&self, part_index: usize, n_bytes: usize, time: std::time::Duration) {
-        self.0.chunk_completed(part_index, n_bytes, time);
-        self.1.chunk_completed(part_index, n_bytes, time);
-    }
-
-    fn part_started(&self, part_index: usize, range: crate::InclusiveRange) {
-        self.0.part_started(part_index, range);
-        self.1.part_started(part_index, range);
-    }
-
-    fn part_completed(
-        &self,
-        part_index: usize,
-        n_chunks: usize,
-        n_bytes: usize,
-        time: std::time::Duration,
-    ) {
-        self.0.part_completed(part_index, n_chunks, n_bytes, time);
-        self.1.part_completed(part_index, n_chunks, n_bytes, time);
-    }
-}
