@@ -5,7 +5,8 @@ use futures::future::BoxFuture;
 
 use crate::{
     condow_client::CondowClient,
-    errors::{CondowError, GetSizeError},
+    errors::CondowError,
+    machinery,
     reporter::{NoReporting, Reporter, ReporterFactory},
     streams::{ChunkStream, PartStream},
     Condow, DownloadRange, Downloads, GetSizeMode, StreamWithReport,
@@ -51,10 +52,12 @@ impl<C: CondowClient, RF: ReporterFactory> Downloader<C, RF> {
         self
     }
 
+    /// Set or replace the [ReporterFactory] in a builder style
     pub fn with_reporting<RRF: ReporterFactory>(self, rep_fac: RRF) -> Downloader<C, RRF> {
         self.with_reporting_arc(Arc::new(rep_fac))
     }
 
+    /// Set or replace the [ReporterFactory] in a builder style
     pub fn with_reporting_arc<RRF: ReporterFactory>(self, rep_fac: Arc<RRF>) -> Downloader<C, RRF> {
         let Downloader {
             get_size_mode,
@@ -94,10 +97,15 @@ impl<C: CondowClient, RF: ReporterFactory> Downloader<C, RF> {
         location: C::Location,
         range: R,
     ) -> Result<ChunkStream, CondowError> {
-        self.condow
-            .download_chunks_internal(location, range, self.get_size_mode, NoReporting)
-            .await
-            .map(|o| o.stream)
+        machinery::start_download(
+            &self.condow,
+            location,
+            range,
+            self.get_size_mode,
+            NoReporting,
+        )
+        .await
+        .map(|o| o.stream)
     }
 
     /// Download the BLOB/range and report events.
@@ -163,13 +171,11 @@ impl<C: CondowClient, RF: ReporterFactory> Downloader<C, RF> {
         range: R,
         reporter: RP,
     ) -> Result<StreamWithReport<ChunkStream, RP>, CondowError> {
-        self.condow
-            .download_chunks_internal(location, range, self.get_size_mode, reporter)
-            .await
+        machinery::start_download(&self.condow, location, range, self.get_size_mode, reporter).await
     }
 
-    /// Get the size of a file at the BLOB at location
-    pub async fn get_size(&self, location: C::Location) -> Result<usize, GetSizeError> {
+    /// Get the size of a BLOB at location
+    pub async fn get_size(&self, location: C::Location) -> Result<usize, CondowError> {
         self.condow.get_size(location).await
     }
 }
