@@ -23,9 +23,9 @@ use futures::{future::BoxFuture, Stream};
 
 use condow_client::CondowClient;
 use config::{AlwaysGetSize, Config};
-use errors::{CondowError, GetSizeError};
+use errors::CondowError;
 use reporter::{NoReporting, Reporter, ReporterFactory};
-use streams::{BytesHint, ChunkStream, ChunkStreamItem, PartStream};
+use streams::{ChunkStream, ChunkStreamItem, PartStream};
 
 #[macro_use]
 pub(crate) mod helpers;
@@ -146,7 +146,7 @@ impl<C: CondowClient> Condow<C> {
         location: C::Location,
         range: R,
     ) -> Result<ChunkStream, CondowError> {
-        self.download_chunks_internal(location, range, GetSizeMode::Default, NoReporting)
+        machinery::start_download(&self, location, range, GetSizeMode::Default, NoReporting)
             .await
             .map(|o| o.into_stream())
     }
@@ -159,70 +159,17 @@ impl<C: CondowClient> Condow<C> {
         location: C::Location,
         range: R,
     ) -> Result<PartStream<ChunkStream>, CondowError> {
-        let chunk_stream = self
-            .download_chunks_internal(location, range, GetSizeMode::Default, NoReporting)
-            .await
-            .map(|o| o.into_stream())?;
+        let chunk_stream =
+            machinery::start_download(&self, location, range, GetSizeMode::Default, NoReporting)
+                .await
+                .map(|o| o.into_stream())?;
         PartStream::from_chunk_stream(chunk_stream)
     }
 
     /// Get the size of a file at the given location
-    pub async fn get_size(&self, location: C::Location) -> Result<usize, GetSizeError> {
+    pub async fn get_size(&self, location: C::Location) -> Result<usize, CondowError> {
         self.client.get_size(location).await
     }
-
-    async fn download_chunks_internal<R: Into<DownloadRange>, RP: Reporter>(
-        &self,
-        location: C::Location,
-        range: R,
-        get_size_mode: GetSizeMode,
-        reporter: RP,
-    ) -> Result<StreamWithReport<ChunkStream, RP>, CondowError> {
-        let range: DownloadRange = range.into();
-        range.validate()?;
-        let range = if let Some(range) = range.sanitized() {
-            range
-        } else {
-            return Ok(StreamWithReport::new(ChunkStream::empty(), reporter));
-        };
-
-        let (inclusive_range, bytes_hint) = match range {
-            DownloadRange::Open(or) => {
-                let size = self.client.get_size(location.clone()).await?;
-                if let Some(range) = or.incl_range_from_size(size) {
-                    (range, BytesHint::new_exact(range.len()))
-                } else {
-                    return Ok(StreamWithReport::new(ChunkStream::empty(), reporter));
-                }
-            }
-            DownloadRange::Closed(cl) => {
-                if get_size_mode.is_load_size_enforced(self.config.always_get_size) {
-                    let size = self.client.get_size(location.clone()).await?;
-                    if let Some(range) = cl.incl_range_from_size(size) {
-                        (range, BytesHint::new_exact(range.len()))
-                    } else {
-                        return Ok(StreamWithReport::new(ChunkStream::empty(), reporter));
-                    }
-                } else if let Some(range) = cl.incl_range() {
-                    (range, BytesHint::new_at_max(range.len()))
-                } else {
-                    return Ok(StreamWithReport::new(ChunkStream::empty(), reporter));
-                }
-            }
-        };
-
-        let stream = machinery::download(
-            self.client.clone(),
-            location,
-            inclusive_range,
-            bytes_hint,
-            self.config.clone(),
-            reporter.clone(),
-        )
-        .await?;
-
-        Ok(StreamWithReport { reporter, stream })
-    }
 }
 
 impl<C> Downloads<C::Location> for Condow<C>
