@@ -3,7 +3,7 @@
 //! This goes more into the direction of instrumentation. Unfortunately
 //! `tokio` uses the word `Instrumentation` already for their tracing
 //! implementation.
-use std::time::Duration;
+use std::{fmt, time::Duration};
 
 use crate::InclusiveRange;
 
@@ -27,7 +27,7 @@ pub trait ReporterFactory: Send + Sync + 'static {
 /// downloading too much with measuring.
 #[allow(unused_variables)]
 pub trait Reporter: Clone + Send + Sync + 'static {
-    /// The effective range which is downloaded (and split into parts)
+    fn location(&self, location: &dyn fmt::Display) {}
     fn effective_range(&self, range: InclusiveRange) {}
     /// The actual IO started
     fn download_started(&self) {}
@@ -62,9 +62,69 @@ impl ReporterFactory for NoReporting {
     }
 }
 
+/// Plug 2 [Reporter]s into one and have them both notified.
+///
+/// `RA` is notified first.
+#[derive(Clone)]
+pub struct CompositeReporter<RA: Reporter, RB: Reporter>(pub RA, pub RB);
+
+impl<RA: Reporter, RB: Reporter> Reporter for CompositeReporter<RA, RB> {
+    fn location(&self, location: &dyn fmt::Display) {
+        self.0.location(location);
+        self.1.location(location);
+    }
+
+    fn effective_range(&self, range: InclusiveRange) {
+        self.0.effective_range(range);
+        self.1.effective_range(range);
+    }
+
+    fn download_started(&self) {
+        self.0.download_started();
+        self.1.download_started();
+    }
+
+    fn download_completed(&self) {
+        self.0.download_completed();
+        self.1.download_completed();
+    }
+
+    fn download_failed(&self) {
+        self.0.download_failed();
+        self.1.download_failed();
+    }
+
+    fn queue_full(&self) {
+        self.0.queue_full();
+        self.1.queue_full();
+    }
+
+    fn chunk_completed(&self, part_index: usize, n_bytes: usize, time: std::time::Duration) {
+        self.0.chunk_completed(part_index, n_bytes, time);
+        self.1.chunk_completed(part_index, n_bytes, time);
+    }
+
+    fn part_started(&self, part_index: usize, range: crate::InclusiveRange) {
+        self.0.part_started(part_index, range);
+        self.1.part_started(part_index, range);
+    }
+
+    fn part_completed(
+        &self,
+        part_index: usize,
+        n_chunks: usize,
+        n_bytes: usize,
+        time: std::time::Duration,
+    ) {
+        self.0.part_completed(part_index, n_chunks, n_bytes, time);
+        self.1.part_completed(part_index, n_chunks, n_bytes, time);
+    }
+}
+
 mod simple_reporter {
-    //! Simple reporting with counters
+    //! Simple reporting with (mostly) counters
     use std::{
+        fmt,
         sync::{
             atomic::{AtomicBool, AtomicU64, AtomicUsize, Ordering},
             Arc, Mutex,
@@ -72,6 +132,8 @@ mod simple_reporter {
         time::{Duration, Instant},
     };
 
+    use crate::InclusiveRange;
+
     use super::{Reporter, ReporterFactory};
 
     /// Creates [SimpleReporter]s
@@ -125,6 +187,8 @@ mod simple_reporter {
             };
 
             SimpleReport {
+                location: inner.location.lock().unwrap().clone(),
+                effective_range: *inner.effective_range.lock().unwrap(),
                 is_finished: self.is_download_finished(),
                 is_failed: inner.is_failed.load(Ordering::SeqCst),
                 download_time,
@@ -145,8 +209,8 @@ mod simple_reporter {
                 max_part_bytes: inner.max_part_bytes.load(Ordering::SeqCst),
                 min_chunks_per_part: inner.min_chunks_per_part.load(Ordering::SeqCst),
                 max_chunks_per_part: inner.max_chunks_per_part.load(Ordering::SeqCst),
-                min_part_time: Duration::from_millis(inner.min_part_ms.load(Ordering::SeqCst)),
-                max_part_time: Duration::from_millis(inner.max_part_ms.load(Ordering::SeqCst)),
+                min_part_time: Duration::from_micros(inner.min_part_us.load(Ordering::SeqCst)),
+                max_part_time: Duration::from_micros(inner.max_part_us.load(Ordering::SeqCst)),
             }
         }
     }
@@ -159,6 +223,8 @@ mod simple_reporter {
 
     #[derive(Debug, Clone)]
     pub struct SimpleReport {
+        pub location: String,
+        pub effective_range: Option<InclusiveRange>,
         /// `true` if the download was finished
         pub is_finished: bool,
         pub is_failed: bool,
@@ -187,6 +253,18 @@ mod simple_reporter {
     }
 
     impl Reporter for SimpleReporter {
+        fn location(&self, location: &dyn fmt::Display) {
+            self.inner
+                .location
+                .lock()
+                .unwrap()
+                .push_str(&location.to_string());
+        }
+
+        fn effective_range(&self, effective_range: InclusiveRange) {
+            *self.inner.effective_range.lock().unwrap() = Some(effective_range);
+        }
+
         fn download_started(&self) {
             *self.inner.download_started_at.lock().unwrap() = Instant::now();
         }
@@ -232,13 +310,15 @@ mod simple_reporter {
             inner
                 .max_chunks_per_part
                 .fetch_max(n_chunks, Ordering::SeqCst);
-            let ms = time.as_millis() as u64;
-            inner.min_part_ms.fetch_min(ms, Ordering::SeqCst);
-            inner.max_part_ms.fetch_max(ms, Ordering::SeqCst);
+            let ms = time.as_micros() as u64;
+            inner.min_part_us.fetch_min(ms, Ordering::SeqCst);
+            inner.max_part_us.fetch_max(ms, Ordering::SeqCst);
         }
     }
 
     struct Inner {
+        location: Mutex<String>,
+        effective_range: Mutex<Option<InclusiveRange>>,
         download_started_at: Mutex<Instant>,
         download_finished_at: Mutex<Option<Instant>>,
         is_failed: AtomicBool,
@@ -254,13 +334,15 @@ mod simple_reporter {
         max_part_bytes: AtomicUsize,
         min_chunks_per_part: AtomicUsize,
         max_chunks_per_part: AtomicUsize,
-        min_part_ms: AtomicU64,
-        max_part_ms: AtomicU64,
+        min_part_us: AtomicU64,
+        max_part_us: AtomicU64,
     }
 
     impl Inner {
         fn new() -> Self {
             Inner {
+                location: Mutex::new(String::new()),
+                effective_range: Mutex::new(None),
                 download_started_at: Mutex::new(Instant::now()),
                 download_finished_at: Mutex::new(None),
                 is_failed: AtomicBool::new(false),
@@ -276,8 +358,8 @@ mod simple_reporter {
                 max_part_bytes: AtomicUsize::new(0),
                 min_chunks_per_part: AtomicUsize::new(usize::MAX),
                 max_chunks_per_part: AtomicUsize::new(0),
-                min_part_ms: AtomicU64::new(u64::MAX),
-                max_part_ms: AtomicU64::new(0),
+                min_part_us: AtomicU64::new(u64::MAX),
+                max_part_us: AtomicU64::new(0),
             }
         }
     }
